summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFrédéric Guillot <contact@fredericguillot.com>2014-02-21 17:04:41 -0500
committerFrédéric Guillot <contact@fredericguillot.com>2014-02-21 17:04:41 -0500
commit4bf0e61cc42db668bc2e967c3901f587b9468b86 (patch)
tree05669a57f01ee67e2f9b958a219f6a1b55f23906
parent03c380217afd991288764392a6587d261708d48b (diff)
Change PHP requirements
-rw-r--r--check_setup.php11
1 files changed, 8 insertions, 3 deletions
diff --git a/check_setup.php b/check_setup.php
index 46260ff1..a2ad30db 100644
--- a/check_setup.php
+++ b/check_setup.php
@@ -1,8 +1,8 @@
<?php
// PHP 5.3 minimum
-if (version_compare(PHP_VERSION, '5.3.7', '<')) {
- die('This software require PHP 5.3.7 minimum');
+if (version_compare(PHP_VERSION, '5.3.3', '<')) {
+ die('This software require PHP 5.3.3 minimum');
}
// Short tags must be enabled for PHP < 5.4
@@ -13,11 +13,16 @@ if (version_compare(PHP_VERSION, '5.4.0', '<')) {
}
}
// Check PDO Sqlite
if (! extension_loaded('pdo_sqlite')) {
die('PHP extension required: pdo_sqlite');
}
+// Check extension: mbstring
+if (! extension_loaded('mbstring')) {
+ die('PHP extension required: mbstring');
+}
+
// Check if /data is writeable
if (! is_writable('data')) {
die('The directory "data" must be writeable by your web server user');
@@ -13,11 +13,16 @@ if (version_compare(PHP_VERSION, '5.4.0', '<')) {
}
}
-// Check PDO Sqlite
+// Check extension: PDO Sqlite
if (! extension_loaded('pdo_sqlite')) {
die('PHP extension required: pdo_sqlite');